==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/include/useradminform.php <==
<?php
// $Id: useradminform.php,v 1.4 2005/08/11 02:00:30 tani Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

include_once XOOPS_ROOT_PATH."/class/xoopslists.php";
include_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";

include_once XOOPS_ROOT_PATH."/modules/xoonips/condefs.php";

$config_handler =& xoops_gethandler('config');
$xoopsConfigUser =& $config_handler->getConfigsByCat(XOOPS_CONF_USER);

// acquire required flags of XooNIps user information
$val='';
$required = array();
foreach( array( 'realname', 'address', 'division', 'tel', 'company_name', 'country', 'zipcode', 'fax' ) as $k ){
	if( xnp_get_config_value( "account_${k}_optional", $val ) == RES_OK ){
		if( $val != 'on' ){
			$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
			$required[$k]['flag'] = true;
		}else{
			$required[$k]['mark'] = '';
			$required[$k]['flag'] = false;
		}
	}else{
		// require if not configured
		$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
		$required[$k]['flag'] = true;
	}
}

$uid_label = new XoopsFormLabel(_AM_USERID, $uid_value);
$uname_text = new XoopsFormText(_AM_NICKNAME._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "username", 25, 25, $uname_value);
$name_text = new XoopsFormText(_AM_NAME.$required['realname']['mark'], "name", 30, 60, $name_value);
$email_tray = new XoopsFormElementTray(_AM_EMAIL._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "<br />");
$email_text = new XoopsFormText("", "email", 30, 60, $email_value);
$email_tray->addElement($email_text, true);
$email_cbox = new XoopsFormCheckBox("", "user_viewemail", $email_cbox_value);
$email_cbox->addOption(1, _AM_AOUTVTEAD);
$email_tray->addElement($email_cbox);
$url_text = new XoopsFormText(_AM_URL, "url", 30, 100, $url_value);
//	$avatar_select = new XoopsFormSelect("", "user_avatar", $avatar_value);
//	$avatar_array = XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//	$avatar_select->addOptionArray($avatar_array);
//	$a_dirlist = XoopsLists::getDirListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//	$a_dir_labels = array();
//	$a_count = 0;
//	$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;start=".$a_count."','avatars',600,400);\">XOOPS</a>";
//	$a_count = $a_count + count($avatar_array);
//	$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//	foreach ($a_dirlist as $a_dir) {
//		if ( $a_dir == "users" ) {
//			continue;
//		}
//		$avatars_array = XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/".$a_dir."/", $a_dir."/");
//		$avatar_select->addOptionArray($avatars_array);
//		$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;subdir=".$a_dir."&amp;start=".$a_count."','avatars',600,400);\">".$a_dir."</a>";
//		$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//		$a_count = $a_count + count($avatars_array);
//	}
//	if (!empty($uid_value)) {
//		$myavatar = avatarExists($uid_value);
//		if ( $myavatar != false ) {
//			$avatar_select->addOption($myavatar, _US_MYAVATAR);
//		}
//	}
//	$avatar_select->setExtra("onchange='showImgSelected(\"avatar\", \"user_avatar\", \"images/avatar\", \"\", \"".XOOPS_URL."\")'");
//	$avatar_label = new XoopsFormLabel("", "<img src='".XOOPS_URL."/images/avatar/".$avatar_value."' name='avatar' id='avatar' alt='' />");
//	$avatar_tray = new XoopsFormElementTray(_AM_AVATAR, "&nbsp;");
//	$avatar_tray->addElement($avatar_select);
//	$avatar_tray->addElement($avatar_label);
//	foreach ($a_dir_labels as $a_dir_label) {
//		$avatar_tray->addElement($a_dir_label);
//	}
//	$theme_select = new XoopsFormSelectTheme(_AM_THEME, "theme", $theme_value);
$timezone_select = new XoopsFormSelectTimezone(_US_TIMEZONE, "timezone_offset", $timezone_value);
// start of XooNIps user info
$address_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_ADDRESS.$required['address']['mark'], 'address', 60, 255, $address_value);
$division_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_DIVISION.$required['division']['mark'], 'division', 60, 255, $division_value);
$tel_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_TEL.$required['tel']['mark'], 'tel', 25, 32, $tel_value);
$fax_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_FAX.$required['fax']['mark'], 'fax', 25, 32, $fax_value);
$company_name_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_COMPANY_NAME.$required['company_name']['mark'], 'company_name', 60, 255, $company_name_value);
$country_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_COUNTRY.$required['country']['mark'], 'country', 25, 255, $country_value);
$zipcode_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_ZIPCODE.$required['zipcode']['mark'], 'zipcode', 20, 32, $zipcode_value);
$notice_mail_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_NOTICE_MAIL, "notice_mail", 5, 10, isset( $notice_mail_value ) || $notice_mail_value!="" ? $notice_mail_value : 0 );
$private_item_number_limit_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_NUMBER_LIMIT , "private_item_number_limit" , 5, 10, isset( $private_item_number_limit_value  ) ? $private_item_number_limit_value  : ""  );
$private_index_number_limit_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_PRIVATE_INDEX_NUMBER_LIMIT, "private_index_number_limit", 5, 10, isset( $private_index_number_limit_value ) ? $private_index_number_limit_value : ""  );
$private_item_storage_limit_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_STORAGE_LIMIT, "private_item_storage_limit", 5, 10, isset( $private_item_storage_limit_value ) ? $private_item_storage_limit_value : ""  );
// end of XooNIps user info
$icq_text = new XoopsFormText(_AM_ICQ, "user_icq", 15, 15, $icq_value);
$aim_text = new XoopsFormText(_AM_AIM, "user_aim", 18, 18, $aim_value);
$yim_text = new XoopsFormText(_AM_YIM, "user_yim", 25, 25, $yim_value);
$msnm_text = new XoopsFormText(_AM_MSNM, "user_msnm", 30, 100, $msnm_value);
$location_text = new XoopsFormText(_AM_LOCATION, "user_from", 30, 100, $location_value);
$occupation_text = new XoopsFormText(_AM_OCCUPATION, "user_occ", 30, 100, $occ_value);
$interest_text = new XoopsFormText(_AM_INTEREST, "user_intrest", 30, 150, $interest_value);
$sig_tray = new XoopsFormElementTray(_AM_SIGNATURE, "<br />");
$sig_tarea = new XoopsFormTextArea("", "user_sig", $sig_value);
$sig_tray->addElement($sig_tarea);
$sig_cbox = new XoopsFormCheckBox("", "attachsig", $sig_cbox_value);
$sig_cbox->addOption(1, _US_SHOWSIG);
$sig_tray->addElement($sig_cbox);
$umode_select = new XoopsFormSelect(_US_CDISPLAYMODE, "umode", $umode_value);
$umode_select->addOptionArray(array("nest"=>_NESTED, "flat"=>_FLAT, "thread"=>_THREADED));
$uorder_select = new XoopsFormSelect(_US_CSORTORDER, "uorder", $uorder_value);
$uorder_select->addOptionArray(array("0"=>_OLDESTFIRST, "1"=>_NEWESTFIRST));
// RMV-NOTIFY
include_once XOOPS_ROOT_PATH. '/language/' . $xoopsConfig['language'] . '/notification.php';
include_once XOOPS_ROOT_PATH . '/include/notification_constants.php';
$notify_method_select = new XoopsFormSelect(_NOT_NOTIFYMETHOD, 'notify_method', $notify_method_value);
$notify_method_select->addOptionArray(array(XOOPS_NOTIFICATION_METHOD_DISABLE=>_NOT_METHOD_DISABLE, XOOPS_NOTIFICATION_METHOD_PM=>_NOT_METHOD_PM, XOOPS_NOTIFICATION_METHOD_EMAIL=>_NOT_METHOD_EMAIL));
$notify_mode_select = new XoopsFormSelect(_NOT_NOTIFYMODE, 'notify_mode', $notify_mode_value);
$notify_mode_select->addOptionArray(array(XOOPS_NOTIFICATION_MODE_SENDALWAYS=>_NOT_MODE_SENDALWAYS, XOOPS_NOTIFICATION_MODE_SENDONCETHENDELETE=>_NOT_MODE_SENDONCE, XOOPS_NOTIFICATION_MODE_SENDONCETHENWAIT=>_NOT_MODE_SENDONCEPERLOGIN));
$bio_tarea = new XoopsFormTextArea(_US_EXTRAINFO, "bio", $bio_value);
$rank_select = new XoopsFormSelect(_AM_RANK, "rank", $rank_value);
$ranklist = XoopsLists::getUserRankList();
if ( count($ranklist) > 0 ) {
	$rank_select->addOption(0, _AM_NSRA);
	$rank_select->addOption(0, "--------------");
	$rank_select->addOptionArray($ranklist);
} else {
	$rank_select->addOption(0, _AM_NSRID);
}
if (!$form_isedit) {
	$pwd_text = new XoopsFormPassword(_AM_PASSWORD._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "password", 10, 32);
	$pwd_text2 = new XoopsFormPassword(_AM_RETYPEPD._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "pass2", 10, 32);
}else{
	$pwd_text = new XoopsFormPassword(_AM_PASSWORD, "password", 10, 32);
	$pwd_text2 = new XoopsFormPassword(_AM_RETYPEPD, "pass2", 10, 32);
}
$mailok_radio = new XoopsFormRadioYN(_US_MAILOK, 'user_mailok', $mailok_value);

// Groups administration addition XOOPS 2.0.9: Mith
global $xoopsUser;
$gperm_handler =& xoops_gethandler('groupperm');
//If user has admin rights on groups
if ($gperm_handler->checkRight("system_admin", XOOPS_SYSTEM_GROUP, $xoopsUser->getGroups(), 1)) {
    //add group selection
    $group_select = new XoopsFormSelectGroup(_US_GROUPS, 'groups', false, $groups, 5, true);
}
else {
    //add empty variable
    $group_select = new XoopsFormHidden('groups[]', XOOPS_GROUP_USERS);
}

$fct_hidden = new XoopsFormHidden("fct", "users");
$op_hidden = new XoopsFormHidden("op", $op_value);
$submit_button = new XoopsFormButton("", "submit", _SUBMIT, "submit");

$form = new XoopsThemeForm($form_title, "userinfo", "useradmin.php");
$form->addElement($uname_text, true);
$form->addElement($name_text, $required['realname']['flag']);
$form->addElement($email_tray, true);
$form->addElement($url_text);
//	$form->addElement($avatar_tray);
//	$form->addElement($theme_select);
$form->addElement($timezone_select);
// start of XooNIps user info
$form->addElement($address_text, $required['address']['flag']);
$form->addElement($division_text, $required['division']['flag']);
$form->addElement($tel_text, $required['tel']['flag']);
$form->addElement($fax_text, $required['fax']['flag']);
$form->addElement($company_name_text, $required['company_name']['flag']);
$form->addElement($country_text, $required['country']['flag']);
$form->addElement($zipcode_text, $required['zipcode']['flag']);
$form->addElement($notice_mail_text);
$form->addElement($private_item_number_limit_text);
$form->addElement($private_index_number_limit_text);
$form->addElement($private_item_storage_limit_text);
// end of XooNIps user info
$form->addElement($icq_text);
$form->addElement($aim_text);
$form->addElement($yim_text);
$form->addElement($msnm_text);
$form->addElement($location_text);
$form->addElement($occupation_text);
$form->addElement($interest_text);
$form->addElement($sig_tray);
$form->addElement($umode_select);
$form->addElement($uorder_select);
// RMV-NOTIFY
$form->addElement($notify_method_select);
$form->addElement($notify_mode_select);
$form->addElement($bio_tarea);
$form->addElement($rank_select);
// adding a new user requires password fields
if (!$form_isedit) {
	$form->addElement($pwd_text, true);
	$form->addElement($pwd_text2, true);
} else {
	$form->addElement($pwd_text);
	$form->addElement($pwd_text2);
}
$form->addElement($mailok_radio);
$form->addElement($group_select);
$form->addElement($fct_hidden);
$form->addElement($op_hidden);
$form->addElement($submit_button);
if ( !empty($uid_value) ) {
	$uid_hidden = new XoopsFormHidden("uid", $uid_value);
	$form->addElement($uid_hidden);
}
//$form->setRequired($uname_text);
//$form->setRequired($email_text);
$form->display();

?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/include/useradminform.php <==
<?php
// $Id: useradminform.php,v 1.7 2006/06/22 08:33:54 makotonton Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

include_once XOOPS_ROOT_PATH."/class/xoopslists.php";
include_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";

include_once XOOPS_ROOT_PATH."/modules/xoonips/condefs.php";

$config_handler =& xoops_gethandler('config');
$xoopsConfigUser =& $config_handler->getConfigsByCat(XOOPS_CONF_USER);

// acquire required flags of XooNIps user information
$val='';
$required = array();
foreach( array( 'realname', 'address', 'division', 'tel', 'company_name', 'country', 'zipcode', 'fax' ) as $k ){
	if( xnp_get_config_value( "account_${k}_optional", $val ) == RES_OK ){
		if( $val != 'on' ){
			$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
			$required[$k]['flag'] = true;
		}else{
			$required[$k]['mark'] = '';
			$required[$k]['flag'] = false;
		}
	}else{
		// require if not configured
		$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
		$required[$k]['flag'] = true;
	}
}

$uid_label = new XoopsFormLabel(_AM_USERID, $uid_value);
$uname_text = new XoopsFormText(_AM_NICKNAME._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "username", 25, 25, $uname_value);
$name_text = new XoopsFormText(_AM_NAME.$required['realname']['mark'], "name", 30, 60, $name_value);
$email_tray = new XoopsFormElementTray(_AM_EMAIL._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "<br />");
$email_text = new XoopsFormText("", "email", 30, 60, $email_value);
$email_tray->addElement($email_text, true);
$email_cbox = new XoopsFormCheckBox("", "user_viewemail", $email_cbox_value);
$email_cbox->addOption(1, _AM_AOUTVTEAD);
$email_tray->addElement($email_cbox);
$url_text = new XoopsFormText(_AM_URL, "url", 30, 100, $url_value);
//	$avatar_select = new XoopsFormSelect("", "user_avatar", $avatar_value);
//	$avatar_array = XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//	$avatar_select->addOptionArray($avatar_array);
//	$a_dirlist = XoopsLists::getDirListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//	$a_dir_labels = array();
//	$a_count = 0;
//	$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;start=".$a_count."','avatars',600,400);\">XOOPS</a>";
//	$a_count = $a_count + count($avatar_array);
//	$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//	foreach ($a_dirlist as $a_dir) {
//		if ( $a_dir == "users" ) {
//			continue;
//		}
//		$avatars_array = XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/".$a_dir."/", $a_dir."/");
//		$avatar_select->addOptionArray($avatars_array);
//		$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;subdir=".$a_dir."&amp;start=".$a_count."','avatars',600,400);\">".$a_dir."</a>";
//		$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//		$a_count = $a_count + count($avatars_array);
//	}
//	if (!empty($uid_value)) {
//		$myavatar = avatarExists($uid_value);
//		if ( $myavatar != false ) {
//			$avatar_select->addOption($myavatar, _US_MYAVATAR);
//		}
//	}
//	$avatar_select->setExtra("onchange='showImgSelected(\"avatar\", \"user_avatar\", \"images/avatar\", \"\", \"".XOOPS_URL."\")'");
//	$avatar_label = new XoopsFormLabel("", "<img src='".XOOPS_URL."/images/avatar/".$avatar_value."' name='avatar' id='avatar' alt='' />");
//	$avatar_tray = new XoopsFormElementTray(_AM_AVATAR, "&nbsp;");
//	$avatar_tray->addElement($avatar_select);
//	$avatar_tray->addElement($avatar_label);
//	foreach ($a_dir_labels as $a_dir_label) {
//		$avatar_tray->addElement($a_dir_label);
//	}
//	$theme_select = new XoopsFormSelectTheme(_AM_THEME, "theme", $theme_value);
$timezone_select = new XoopsFormSelectTimezone(_US_TIMEZONE, "timezone_offset", $timezone_value);
// start of XooNIps user info
$division_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_DIVISION.$required['division']['mark'], 'division', 60, 255, $division_value);
$company_name_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_COMPANY_NAME.$required['company_name']['mark'], 'company_name', 60, 255, $company_name_value);
$tel_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_TEL.$required['tel']['mark'], 'tel', 25, 32, $tel_value);
$fax_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_FAX.$required['fax']['mark'], 'fax', 25, 32, $fax_value);
$address_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_ADDRESS.$required['address']['mark'], 'address', 60, 255, $address_value);
$country_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_COUNTRY.$required['country']['mark'], 'country', 25, 255, $country_value);
$zipcode_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_ZIPCODE.$required['zipcode']['mark'], 'zipcode', 20, 32, $zipcode_value);
$notice_mail_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_NOTICE_MAIL, "notice_mail", 5, 10, isset( $notice_mail_value ) || $notice_mail_value!="" ? $notice_mail_value : 0 );
$private_item_number_limit_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_NUMBER_LIMIT , "private_item_number_limit" , 5, 10, isset( $private_item_number_limit_value  ) ? $private_item_number_limit_value  : ""  );
$private_index_number_limit_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_PRIVATE_INDEX_NUMBER_LIMIT, "private_index_number_limit", 5, 10, isset( $private_index_number_limit_value ) ? $private_index_number_limit_value : ""  );
$private_item_storage_limit_text = new XoopsFormText(_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_STORAGE_LIMIT, "private_item_storage_limit", 5, 10, isset( $private_item_storage_limit_value ) ? $private_item_storage_limit_value : ""  );
// end of XooNIps user info
// $icq_text = new XoopsFormText(_AM_ICQ, "user_icq", 15, 15, $icq_value);
// $aim_text = new XoopsFormText(_AM_AIM, "user_aim", 18, 18, $aim_value);
// $yim_text = new XoopsFormText(_AM_YIM, "user_yim", 25, 25, $yim_value);
// $msnm_text = new XoopsFormText(_AM_MSNM, "user_msnm", 30, 100, $msnm_value);
// $location_text = new XoopsFormText(_AM_LOCATION, "user_from", 30, 100, $location_value);
// $occupation_text = new XoopsFormText(_AM_OCCUPATION, "user_occ", 30, 100, $occ_value);
$interest_text = new XoopsFormText(_AM_INTEREST, "user_intrest", 30, 150, $interest_value);
$sig_tray = new XoopsFormElementTray(_AM_SIGNATURE, "<br />");
$sig_tarea = new XoopsFormTextArea("", "user_sig", $sig_value);
$sig_tray->addElement($sig_tarea);
$sig_cbox = new XoopsFormCheckBox("", "attachsig", $sig_cbox_value);
$sig_cbox->addOption(1, _US_SHOWSIG);
$sig_tray->addElement($sig_cbox);
$umode_select = new XoopsFormSelect(_US_CDISPLAYMODE, "umode", $umode_value);
$umode_select->addOptionArray(array("nest"=>_NESTED, "flat"=>_FLAT, "thread"=>_THREADED));
$uorder_select = new XoopsFormSelect(_US_CSORTORDER, "uorder", $uorder_value);
$uorder_select->addOptionArray(array("0"=>_OLDESTFIRST, "1"=>_NEWESTFIRST));
// RMV-NOTIFY
include_once XOOPS_ROOT_PATH. '/language/' . $xoopsConfig['language'] . '/notification.php';
include_once XOOPS_ROOT_PATH . '/include/notification_constants.php';
$notify_method_select = new XoopsFormSelect(_NOT_NOTIFYMETHOD, 'notify_method', $notify_method_value);
$notify_method_select->addOptionArray(array(XOOPS_NOTIFICATION_METHOD_DISABLE=>_NOT_METHOD_DISABLE, XOOPS_NOTIFICATION_METHOD_PM=>_NOT_METHOD_PM, XOOPS_NOTIFICATION_METHOD_EMAIL=>_NOT_METHOD_EMAIL));
$notify_mode_select = new XoopsFormSelect(_NOT_NOTIFYMODE, 'notify_mode', $notify_mode_value);
$notify_mode_select->addOptionArray(array(XOOPS_NOTIFICATION_MODE_SENDALWAYS=>_NOT_MODE_SENDALWAYS, XOOPS_NOTIFICATION_MODE_SENDONCETHENDELETE=>_NOT_MODE_SENDONCE, XOOPS_NOTIFICATION_MODE_SENDONCETHENWAIT=>_NOT_MODE_SENDONCEPERLOGIN));
// $bio_tarea = new XoopsFormTextArea(_US_EXTRAINFO, "bio", $bio_value);
$rank_select = new XoopsFormSelect(_AM_RANK, "rank", $rank_value);
$ranklist = XoopsLists::getUserRankList();
if ( count($ranklist) > 0 ) {
	$rank_select->addOption(0, _AM_NSRA);
	$rank_select->addOption(0, "--------------");
	$rank_select->addOptionArray($ranklist);
} else {
	$rank_select->addOption(0, _AM_NSRID);
}
if (!$form_isedit) {
	$pwd_text = new XoopsFormPassword(_AM_PASSWORD._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "password", 10, 32);
	$pwd_text2 = new XoopsFormPassword(_AM_RETYPEPD._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "pass2", 10, 32);
}else{
	$pwd_text = new XoopsFormPassword(_AM_PASSWORD, "password", 10, 32);
	$pwd_text2 = new XoopsFormPassword(_AM_RETYPEPD, "pass2", 10, 32);
}
$mailok_radio = new XoopsFormRadioYN(_US_MAILOK, 'user_mailok', $mailok_value);

// Groups administration addition XOOPS 2.0.9: Mith
global $xoopsUser;
$gperm_handler =& xoops_gethandler('groupperm');
//If user has admin rights on groups
if ($gperm_handler->checkRight("system_admin", XOOPS_SYSTEM_GROUP, $xoopsUser->getGroups(), 1)) {
    //add group selection
    $group_select = new XoopsFormSelectGroup(_US_GROUPS, 'groups', false, $groups, 5, true);
}
else {
    //add empty variable
    $group_select = new XoopsFormHidden('groups[]', XOOPS_GROUP_USERS);
}

if( isset( $_SESSION['posi_id'] ) ) {
	$posi_select = new XoopsFormSelect(_MD_XOONIPS_ACCOUNT_POSITION, "posi", $_SESSION['posi_id']);
		if( !isset( $_POST['op'] ) ) {
		$posi_select = new XoopsFormSelect(_MD_XOONIPS_ACCOUNT_POSITION, "posi", 0);
		$_SESSION['posi_id'] = "";
	}
} else {
	$posi_select = new XoopsFormSelect(_MD_XOONIPS_ACCOUNT_POSITION, "posi", 0);
}

function getUserPosiList()
{
$db =& Database::getInstance();
$myts =& MyTextSanitizer::getInstance();
$sql = "SELECT posi_id, posi_title FROM ".$db->prefix("xoonips_positions")." ORDER BY posi_order";
$ret = array();
$result = $db->query($sql);
while ( $myrow = $db->fetchArray($result) ) {
		$ret[$myrow['posi_id']] = $myts->makeTboxData4Show($myrow['posi_title']);
	}
return $ret;
}

$posilist =  getUserPosiList();
if ( count($posilist) > 0 ) {
	$posi_select->addOption(0, _AM_NSRA);
	$posi_select->addOption(0, "--------------");
	$posi_select->addOptionArray($posilist);
} else {
	$posi_select->addOption(0, _AM_NSRID);
}
$app_tray = new XoopsFormElementTray(_MD_XOONIPS_ACCOUNT_APPEAL, "<br />");
$app_tarea = new XoopsFormTextArea("", "appeal", $appeal_value);
$app_tray->addElement($app_tarea);
$fct_hidden = new XoopsFormHidden("fct", "users");
$op_hidden = new XoopsFormHidden("op", $op_value);
$submit_button = new XoopsFormButton("", "submit", _SUBMIT, "submit");

$form = new XoopsThemeForm($form_title, "userinfo", "useradmin.php");
$form->addElement($uname_text, true);
$form->addElement($name_text, $required['realname']['flag']);
$form->addElement($email_tray, true);
$form->addElement($url_text);
//	$form->addElement($avatar_tray);
//	$form->addElement($theme_select);
$form->addElement($group_select);
$form->addElement($posi_select);
// start of XooNIps user info
$form->addElement($division_text, $required['division']['flag']);
$form->addElement($company_name_text, $required['company_name']['flag']);
$form->addElement($tel_text, $required['tel']['flag']);
$form->addElement($fax_text, $required['fax']['flag']);
$form->addElement($address_text, $required['address']['flag']);
$form->addElement($country_text, $required['country']['flag']);
$form->addElement($zipcode_text, $required['zipcode']['flag']);
// end of XooNIps user info

$form->addElement($timezone_select);
// $form->addElement($icq_text);
// $form->addElement($aim_text);
// $form->addElement($yim_text);
// $form->addElement($msnm_text);
// $form->addElement($location_text);
// $form->addElement($occupation_text);
$form->addElement($interest_text);
$form->addElement($app_tray);
$form->addElement($sig_tray);
// adding a new user requires password fields
if (!$form_isedit) {
	$form->addElement($pwd_text, true);
	$form->addElement($pwd_text2, true);
} else {
	$form->addElement($pwd_text);
	$form->addElement($pwd_text2);
}
$form->addElement($notice_mail_text);
$form->addElement($private_item_number_limit_text);
$form->addElement($private_index_number_limit_text);
$form->addElement($private_item_storage_limit_text);
$form->addElement($umode_select);
$form->addElement($uorder_select);
$form->addElement($rank_select);
// RMV-NOTIFY
$form->addElement($notify_method_select);
$form->addElement($notify_mode_select);
// $form->addElement($bio_tarea);
$form->addElement($mailok_radio);
$form->addElement($fct_hidden);
$form->addElement($op_hidden);
$form->addElement($submit_button);
if ( !empty($uid_value) ) {
	$uid_hidden = new XoopsFormHidden("uid", $uid_value);
	$form->addElement($uid_hidden);
}
//$form->setRequired($uname_text);
//$form->setRequired($email_text);
$form->display();

?>
